==> grafana-alloy-debug-1.11.2-3-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.44.0/api/datadogV2/model_shift.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// Shift The definition of `Shift` object.
type Shift struct {
	// The definition of `ShiftData` object.
	Data *ShiftData `json:"data,omitempty"`
	// The `Shift` `included`.
	Included []ShiftIncluded `json:"included,omitempty"`
	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
	UnparsedObject       map[string]interface{} `json:"-"`
	AdditionalProperties map[string]interface{} `json:"-"`
}

// NewShift instantiates a new Shift object.
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed.
func NewShift() *Shift {
	this := Shift{}
	return &this
}

// NewShiftWithDefaults instantiates a new Shift object.
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set.
func NewShiftWithDefaults() *Shift {
	this := Shift{}
	return &this
}

// GetData returns the Data field value if set, zero value otherwise.
func (o *Shift) GetData() ShiftData {
	if o == nil || o.Data == nil {
		var ret ShiftData
		return ret
	}
	return *o.Data
}

// GetDataOk returns a tuple with the Data field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Shift) GetDataOk() (*ShiftData, bool) {
	if o == nil || o.Data == nil {
		return nil, false
	}
	return o.Data, true
}

// HasData returns a boolean if a field has been set.
func (o *Shift) HasData() bool {
	return o != nil && o.Data != nil
}

// SetData gets a reference to the given ShiftData and assigns it to the Data field.
func (o *Shift) SetData(v ShiftData) {
	o.Data = &v
}

// GetIncluded returns the Included field value if set, zero value otherwise.
func (o *Shift) GetIncluded() []ShiftIncluded {
	if o == nil || o.Included == nil {
		var ret []ShiftIncluded
		return ret
	}
	return o.Included
}

// GetIncludedOk returns a tuple with the Included field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Shift) GetIncludedOk() (*[]ShiftIncluded, bool) {
	if o == nil || o.Included == nil {
		return nil, false
	}
	return &o.Included, true
}

// HasIncluded returns a boolean if a field has been set.
func (o *Shift) HasIncluded() bool {
	return o != nil && o.Included != nil
}

// SetIncluded gets a reference to the given []ShiftIncluded and assigns it to the Included field.
func (o *Shift) SetIncluded(v []ShiftIncluded) {
	o.Included = v
}

// MarshalJSON serializes the struct using spec logic.
func (o Shift) MarshalJSON() ([]byte, error) {
	toSerialize := map[string]interface{}{}
	if o.UnparsedObject != nil {
		return datadog.Marshal(o.UnparsedObject)
	}
	if o.Data != nil {
		toSerialize["data"] = o.Data
	}
	if o.Included != nil {
		toSerialize["included"] = o.Included
	}

	for key, value := range o.AdditionalProperties {
		toSerialize[key] = value
	}
	return datadog.Marshal(toSerialize)
}

// UnmarshalJSON deserializes the given payload.
func (o *Shift) UnmarshalJSON(bytes []byte) (err error) {
	all := struct {
		Data     *ShiftData      `json:"data,omitempty"`
		Included []ShiftIncluded `json:"included,omitempty"`
	}{}
	if err = datadog.Unmarshal(bytes, &all); err != nil {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}
	additionalProperties := make(map[string]interface{})
	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
		datadog.DeleteKeys(additionalProperties, &[]string{"data", "included"})
	} else {
		return err
	}

	hasInvalidField := false
	if all.Data != nil && all.Data.UnparsedObject != nil && o.UnparsedObject == nil {
		hasInvalidField = true
	}
	o.Data = all.Data
	o.Included = all.Included

	if len(additionalProperties) > 0 {
		o.AdditionalProperties = additionalProperties
	}

	if hasInvalidField {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}

	return nil
}

==> grafana-alloy-debug-1.12.2-1-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.48.0/api/datadogV2/model_shift.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// Shift An on-call shift with its associated data and relationships.
type Shift struct {
	// Data for an on-call shift.
	Data *ShiftData `json:"data,omitempty"`
	// The `Shift` `included`.
	Included []ShiftIncluded `json:"included,omitempty"`
	// UnparsedObject contains the raw value of the object if there was an error when deserializing into the struct
	UnparsedObject       map[string]interface{} `json:"-"`
	AdditionalProperties map[string]interface{} `json:"-"`
}

// NewShift instantiates a new Shift object.
// This constructor will assign default values to properties that have it defined,
// and makes sure properties required by API are set, but the set of arguments
// will change when the set of required properties is changed.
func NewShift() *Shift {
	this := Shift{}
	return &this
}

// NewShiftWithDefaults instantiates a new Shift object.
// This constructor will only assign default values to properties that have it defined,
// but it doesn't guarantee that properties required by API are set.
func NewShiftWithDefaults() *Shift {
	this := Shift{}
	return &this
}

// GetData returns the Data field value if set, zero value otherwise.
func (o *Shift) GetData() ShiftData {
	if o == nil || o.Data == nil {
		var ret ShiftData
		return ret
	}
	return *o.Data
}

// GetDataOk returns a tuple with the Data field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Shift) GetDataOk() (*ShiftData, bool) {
	if o == nil || o.Data == nil {
		return nil, false
	}
	return o.Data, true
}

// HasData returns a boolean if a field has been set.
func (o *Shift) HasData() bool {
	return o != nil && o.Data != nil
}

// SetData gets a reference to the given ShiftData and assigns it to the Data field.
func (o *Shift) SetData(v ShiftData) {
	o.Data = &v
}

// GetIncluded returns the Included field value if set, zero value otherwise.
func (o *Shift) GetIncluded() []ShiftIncluded {
	if o == nil || o.Included == nil {
		var ret []ShiftIncluded
		return ret
	}
	return o.Included
}

// GetIncludedOk returns a tuple with the Included field value if set, nil otherwise
// and a boolean to check if the value has been set.
func (o *Shift) GetIncludedOk() (*[]ShiftIncluded, bool) {
	if o == nil || o.Included == nil {
		return nil, false
	}
	return &o.Included, true
}

// HasIncluded returns a boolean if a field has been set.
func (o *Shift) HasIncluded() bool {
	return o != nil && o.Included != nil
}

// SetIncluded gets a reference to the given []ShiftIncluded and assigns it to the Included field.
func (o *Shift) SetIncluded(v []ShiftIncluded) {
	o.Included = v
}

// MarshalJSON serializes the struct using spec logic.
func (o Shift) MarshalJSON() ([]byte, error) {
	toSerialize := map[string]interface{}{}
	if o.UnparsedObject != nil {
		return datadog.Marshal(o.UnparsedObject)
	}
	if o.Data != nil {
		toSerialize["data"] = o.Data
	}
	if o.Included != nil {
		toSerialize["included"] = o.Included
	}

	for key, value := range o.AdditionalProperties {
		toSerialize[key] = value
	}
	return datadog.Marshal(toSerialize)
}

// UnmarshalJSON deserializes the given payload.
func (o *Shift) UnmarshalJSON(bytes []byte) (err error) {
	all := struct {
		Data     *ShiftData      `json:"data,omitempty"`
		Included []ShiftIncluded `json:"included,omitempty"`
	}{}
	if err = datadog.Unmarshal(bytes, &all); err != nil {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}
	additionalProperties := make(map[string]interface{})
	if err = datadog.Unmarshal(bytes, &additionalProperties); err == nil {
		datadog.DeleteKeys(additionalProperties, &[]string{"data", "included"})
	} else {
		return err
	}

	hasInvalidField := false
	if all.Data != nil && all.Data.UnparsedObject != nil && o.UnparsedObject == nil {
		hasInvalidField = true
	}
	o.Data = all.Data
	o.Included = all.Included

	if len(additionalProperties) > 0 {
		o.AdditionalProperties = additionalProperties
	}

	if hasInvalidField {
		return datadog.Unmarshal(bytes, &o.UnparsedObject)
	}

	return nil
}
